Daily Shaarli
August 10, 2021
Despite the flowery promises in the White House “American Families Plan” Fact Sheet, The Heritage Foundation summed it up as follows.
Biden’s American Families Plan will hurt families. The AFP would increase Washington’s control of preschool, child care, community college, and four-year colleges.
The AFP is a wolf in sheep’s clothing, promising “free” assistance that will result in more debt for our children and grandchildren to pay.
The wolf promises to ease our burdens but, in reality, stands ready to take charge of the decisions that families and communities know how to handle best.
“More debt for our children and families.” Bingo. Including potentially catastrophic financial disasters for untold numbers of those children and families.
Part of Biden’s plan to fund the AFP is by amending federal estate tax law — the so-called “death tax” — that would eliminate stepped-up-basis on appreciated assets inherited by family members, meaning heirs would be forced to pay taxes on assets that increased in value during the lifetime of the deceased relative.
As reported by Just the News, current federal estate tax law — not to be confused with the various state inheritance tax laws — includes a stepped-up basis tax provision that allows an heir to report the value of an asset at the time of inheriting it, thus “stepping up” the cost basis to the current value of an asset at the time of the inheritance, at which point they could sell the asset immediately and essentially avoid paying capital gains taxes, or retain the asset and either sell it later at an appreciated value, at which point they would pay capital gains tax on the increase between the inherited value and the selling price — or retain the asset and pass it to heirs at death. //
If we’re talking investment portfolios — fine; we can have that debate at a later time. But we’re also talking about family farms — many of them, generational family farms — as well as other family businesses. //
One potential family disaster is the fact that most family businesses consist largely of illiquid assets. Large plots of land owned by farmers are a perfect example; the land can often push a modest farm valuation past Biden’s $1 million threshold. //
“Farmers responsibly pay taxes to contribute their fair share to our country. They should not have to face tax burdens to pass their land from one generation to the next. This is how we keep generations of families farming.
“Therefore, we need to maintain protections to ensure the long-term success of family farms. They are the backbone of economic activity in rural areas, and we know the production of food and fiber is a national security issue.” //
Jmied01 • 19 minutes ago
“If we close that loophole, that saves us $400 billion”
Ala Ozark’s Marty Byrde: The *** it Does.
As if merely because it exists, you were always entitled to it? Removing more money from tax payers under implied threat of force is SAVING you money?
Well, I’m just going to rob a bank! I’m only SAVING MONEY. Knocking off the corner store? Creating new income! Nabbing the purse of the little old lady across the street? Generating revenue! //
scgrl625 • an hour ago
Here's some facts. If you plan on leaving your spouse or children anything, set up a revocable trust. If a spouse or child receives your inheritance, they will not have to pay inheritance taxes on the monies and property received from that trust. Also, there are only 6 states in the US that require an inheritance tax. Those states are PA, NE, NJ, MD, KY and IA, but not all tax laws for those states are the same. Some heirs may have to pay, and some may not.
Here's a quote from Smartasset.com, story titled "All About The Inheritance Tax" by Amanda Dixon, dated 7-30-2021.
"If the value of the assets being transferred is higher than the federal estate tax exemption (which is $11.7 million for singles for tax year 2021 and $23.4 million for married couples), the property can be subject to federal estate tax. States have their own exemption thresholds as well. Estate taxes are deducted from the property that’s being passed on before a beneficiary claims it. However, President Joe Biden has proposed eliminating the “stepped-up basis,” a provision that resets the value of inherited property to its current market value when its original owner dies." //
skeptic62 • 6 minutes ago • edited
I would encourage those who would be impacted by Biden’s government seizure by taxation to consider this. Choose a worthy heir early and sell your property, farm or business to your heir for a dollar plus a lifetime lease for you and your spouse. You don’t have to move out of your house. You don’t have to shutter your business. Everything stays pretty much the same. So, when the Grim Reaper comes a callin’ Uncle Sam can only seize your liquid assets. Done right, this would be a much smaller bill. //
johncv skeptic62 • 4 minutes ago
They have you covered with "gift tax" rules. Maximum per year "gifts".
In July, micro-nuclear reactor company Oklo and bitcoin mining company Compass Mining announced a 20-year commercial partnership in which Oklo will eventually power a portion of Compass' mining activities with carbon-free nuclear energy.
Earlier in July, Akron, Ohio-based energy company Energy Harbor Corp. announced it will provide nuclear power to Standard Power's new Bitcoin blockchain mining center in Coshocton, Ohio beginning in December 2021.
The SDF instrument approach is the rarest approach in the USA, with only one example remaining in Morristown, TN. Do you know how to fly it? //
A Simplified Directional Facility Approach (SDF) provides a final approach course similar to a localizer, but with a few distinct differences. //
In 2018, the SDF to RWY 34 at the Marshfield Municipal Airport, Marshfield, WI (KMFI) was decommissioned. This leaves just ONE SDF approach left in the USA, the SDF to Runway 05 at the Moore-Murrell Airport (KMOR), Morristown, Tennessee.
On the surface level, it has everything to do with the fact that he’s got a line of women going out the door that are reporting him for sexual misconduct. On the other, an investigation began into an illegal phone call Cuomo made to the Obama White House about Preet Bharara, a U.S. attorney who was investigating corruption in New York.
The latter is definitely shadier as it loops in other prominent Democrats, including Barack Obama in terms of wrongdoing and unethical behavior. //
While it’s all well and good that Cuomo is ousted for one or both of those things, it’s not right that he’s resigning for either of those reasons. //
Andrew Cuomo should be resigning because he killed 15,000 people.
More importantly, this has some very eye-opening implications on what Democrats actually consider important. The fact that he’s not being forced to resign over killing thousands of Americans, but instead something like groping a few women or endangering the Obama administration should send up so many red flags you’d think this was a Chinese communist party rally. To be clear, groping women without their consent is absolutely awful, but I think the deaths of thousands is a far higher crime.
We are past the point where naivete can be blamed. Rather, probable explanations are now moving toward the realm of the nefarious, either via self-interest or something else. Fauci has had ample opportunity at this point to absorb every negative revelation out of China throughout this pandemic. There is no longer any excuse for him to not affirmatively condemn their actions and pledge to sever the relationship.
That Fauci won’t do that is incredibly disturbing and suspicious.
Yesterday, the CDC reported Florida’s COVID data, something that is part of a normal cycle after a weekend, claiming that the Sunshine State saw over 28,000 new cases on Sunday. That would have been a record high, and it helped drive another round of anti-Florida media coverage.
The problem? The CDC’s reporting was false. //
Florida Dept. Health
@HealthyFla
The number of cases @CDCgov released for Florida today is incorrect. They combined MULTIPLE days into one. We anticipate CDC will correct the record.
WSVN 7 News
@wsvn
Florida reported a record-breaking 28,317 new cases of COVID-19 for Sunday to the CDC.
https://wsvn.com/news/local/florida-reports-record-1-day-total-of-28317-covid-cases-to-cdc/?utm_medium=social&utm_source=twitter_wsvn
8:18 PM · Aug 9, 2021
Taryn Fenske
@tarynfenske
Incorrect. Here’s the data: Friday, August 6 (21,500), Saturday, August 7 (19,567), and Sunday, August 8 (15,319).
Scott Travis
@smtravis
Florida still breaking records for daily COVID cases. Single-day high reaches 28,317 https://sun-sentinel.com/coronavirus/fl-ne-florida-covid-cases-still-breaking-records-20210809-uq2u3bhll5bh3npr6paqb53rwa-story.html //
The conspiracy theory that Florida is misrepresenting COVID data was originally started by Rebekah Jones, a grifter who claimed to be a “data scientist” in charge of Florida’s data entry. But her mantle has been picked up by many, including Feigl-Ding, another person who has used wild COVID allegations to raise their profile.
With Windows 10, the device limits have been reduced to 10:
https://www.thurrott.com/windows/windows-10/4959/ask-paul-what-are-the-windows-10-device-limits
But Digital Licensing is not attached to the Microsoft Account, it is attached to the hardware with the qualifying operating system.
When you upgraded from a previous version of Windows or receive a new computer preinstalled with Windows 10, what happened is the hardware (your PC) will get a digital entitlement, where a unique signature of the computer will be stored on Microsoft Activation Servers. The Windows 7 or Windows 8 genuine license you were previously running will be exchanged for a diagnostics key.
Anytime you need to reinstall Windows 10 on that machine, just proceed to reinstall Windows 10. It will automatically reactivate.
So, there is no need to know or get a product key, if you need to reinstall Windows 10, you can use your Windows 7 or Windows 8 product key or use the reset function in Windows 10.
If you are prompted to enter a product key, click 'I don't have a key' and 'Do this later'
So as long as those systems are activated with Windows 10, Microsoft Account or not, it earns a digital license.
More information:
For anyone else, including those with local or domain accounts, this step is optional. In any case, it applies only to those who have a Windows 10 digital license. That group consists primarily of those who took advantage of the year-long free upgrade offer that ends on July 29, 2016.
This new feature doesn't change the fundamental way that Microsoft's activation servers work. The process of activating Windows relies on a unique installation ID, which is based on a hash of information taken from the hardware on which Windows is installed. That hash is reportedly not reversible and is not tied to any other Microsoft services. It identifies a specific device, not a person.
Michael Beschloss
@BeschlossDC
Evisceration of White House Rose Garden was completed a year ago this month, and here was the grim result—decades of American history made to disappear: //
Office of Melania Trump
@OfficeofMelania
.@BeschlossDC has proven his ignorance by showing a picture of the Rose Garden in its infancy. The Rose Garden is graced with a healthy & colorful blossoming of roses. His misleading information is dishonorable & he should never be trusted as a professional historian. //
Jaye
2 hours ago edited
MSM is only calling it out because Jill Biden tried to call this Rose Garden her own, sending out a lovely photo in full bloom with her Spring Greetings.
Nary a mention of her predecessor who handed Jill Biden this lovely gift, in honor of former FLOTUS Jackie Kennedy, who Melania had honored.
Decency curdles in the hands of both Biden occupants. .
Emirates posted a video of a flight attendant standing at the very top of the Burj Khalifa, and it’s real. A behind the scenes video has now been posted showing how this video was produced, and it’s pretty amazing. And here I was thinking that we were just getting Punk’d…
Create a virtual machine and install its operating system.
We've been building new tools for creating virtual machines so the instructions have changed significantly over the past three releases.
Pick your operating system for the right set of instructions:
- Windows 10 Fall Creators Update (v1709) and later
- Windows 10 Creators Update (v1703)
- Windows 10 Anniversary Update (v1607) and earlier
Mike Rowe
August 8 at 5:41 PM ·
Off the Wall
Here’s a delightful headline, followed by a charming article, written by a guy named Jonathan V. Last. I don’t think he likes me. Strap in. It's a doozy.
MIKE ROWE'S DIRTY LIES
The voice of the working class goes anti-anti-anti-vaxx.
Mike Rowe—the famous real man, dirty-jobbing, tough guy—is trying to pioneer a new lane in political discourse: anti-anti-anti-vaxx. In a Facebook post this week, Rowe decided to answer a question from one of his fans. The gentleman asked why, since Rowe had gotten a COVID vaccine, he had not used his platform to urge others to do so. Rowe’s response is worth reading in full, because it is either an example of despicable dishonesty or breathtaking stupidity.
Hi Jonathan
Along with “despicable dishonesty and breathtaking stupidity,” I’d like to offer a few additional options for you readers to consider. How about, “a refreshingly honest take on a controversial issue,” or “a thoughtful series of observations wrapped in a patina of common sense,” or maybe, “a brilliant blending of facts and inconvenient truths that leave the skeptical reader with much to consider.”
As you surely know, tens of millions of Americans are not even remotely persuaded by our current cadre of elected officials and health care experts. Obviously, the same was true when Trump was in office. Can you imagine the resistance to a vaccine today, if Donald Trump told Americans to simply “get the jab and trust the science?” It seems to me, if you want to persuade the unvaccinated to reconsider their hesitancy, you must first put yourself in their shoes, and acknowledge a few of the reasons for their skepticism.
Also, I’m puzzled by your sub-head. If “anti-vaxx” means I’m against vaccines, “anti-anti-vaxx” would mean I’m for vaccines, right? So, wouldn’t “anti-anti-anti-vaxx” mean I’m against vaccines? If so, you’re fundamentally mistaken. As I wrote in the very first paragraph, “Vaccines have saved more lives than any other advancement in the long history of medicine, and to your point, I got the shots the minute I was eligible.” I was careful to include that early on. You were careful to omit it. Understandable, given your headline, but not very fair, in my opinion.
JL: Rowe begins his explanation by saying, “I’m not a doctor, Steve, and even though I occasionally play one on TV, I’m not inclined to dispense medical advice to the people on this page.” And you know what? That’s fair enough. If Rowe doesn’t feel comfortable telling others what to do when it comes to public health, that’s reasonable. Except that two paragraphs later he starts asking questions about public health.
MR: Not to nitpick but asking questions about public health is very different than telling others what to do. Don’t you think?
JL: Rowe says the following: The fact is, millions of reasonable Americans have every right to feel confused and skeptical. Those people you refer to, Steve – the ones now telling us that we can “get back to normal just as soon as everyone is vaccinated” – those are the same people who said, “two weeks to flatten the curve!” Those are the same people who told us that masks were “useless” before they told us they were “critical.” Those are the same people who told us that a return to normalcy would occur just as soon as “the most vulnerable” among us were vaccinated. Then, just as soon as “half the population” was vaccinated. Then, just as soon as we achieved “herd immunity.” Those are the same people who told us they wouldn’t trust any vaccine developed under the last administration. Now, those very same people are belittling the skeptics.”
For a guy who makes his living pretending to be concerned with grubby details, this is a wildly, irresponsibly generalized set of charges. For starters, who are “those people”? No links here. No names. Just a vague, faceless assertion so he can’t be called out on facts.
MR: It was the original poster, Jonathan, not me, who said that we can “all get back to normal when everyone gets the shot.” He didn’t attribute that sentiment to any one individual, because he didn’t have to. It’s a widely held belief currently embraced by millions of Americans who affirmatively support a vaccine mandate. Check it out. https://53eig.ht/37sBWip
Obviously, I could have provided specific examples of people in power who favored lockdowns but went on to violate their own mandates, but I didn’t do that because those people are no longer the point. The point I was trying to make, is that half the country has lost faith in our most important institutions. We have a massive credibility problem, exacerbated by powerful people who not only moved the goalposts time and time again, but championed the same restrictions they chose to ignore. In my view, this steady drip of hypocrisy helped foster a deep level of mistrust among millions of unvaccinated Americans. If you really need specific examples, just google “COVID-political-hypocrites.” Those are the people to whom I refer, and they are legion.
JL: But the individual characterizations he makes of what “those people” supposedly said are at best misleading and at worst, patently untrue. Let’s go one by one.
“Two weeks to flatten the curve!” The idea of flattening the curve comes from late March 2020, when COVID was starting to run wild in the United States for the first time. The curve in question was the rate of new infections and the curve needed to be flattened because it’s increase was so steep that it was nearly an asymptote. The country faced a shortage of PPE and doctors hadn’t yet come up with best practices for treating patients. Had the rate of infection continued its geometric increase, not only would a higher percentage of COVID patients have died due to lack of adequate resources to care for them, but more non-COVID patients would have died because the healthcare system would have been overrun. The idea of “flattening the curve” was never about beating COVID, but about buying the healthcare system enough time to be able to treat patients optimally. And you know what? We flattened the fucking curve, Mike. And because of that, we saved a lot of lives.
MR: I agree. In just a few weeks, we flattened the curve, and we saved lives as a result. But what did our leaders do next? Did they say, “Good job! The curve is flat! Now let’s get back to work!” No. They extended the lockdowns and offered no benchmark as to when the restrictions would be lifted. To this day, we have no criteria as to how many deaths or how many infections or how many hospitalizations are acceptable. They could have told us the truth a year ago, which was more along the lines of, “Two weeks to flatten the curve, and then, an undetermined amount of time to keep it that way.” But they didn’t do that. They simply shut us down, ratcheted up the fear, and told us to trust the science. In short, they treated us like children, and that hurt their credibility.
JL: “The same people who told us that masks were ‘useless’.” Again, it’s hard to find details about “those people” but I assume Rowe is talking about Anthony Fauci’s comments to CBS News on March 8, 2020 where he said the following: There’s no reason to be walking around with a mask. When you’re in the middle of an outbreak, wearing a mask might make people feel a little bit better and it might even block a droplet, but it’s not providing the perfect protection that people think that it is. And, often, there are unintended consequences — people keep fiddling with the mask and they keep touching their face.
MR: You’re correct, Fauci’s contradictions were on my mind when I wrote that. So too, were his more recent comments regarding the lab leak, gain of function, and lots of other remarks that are now seen by millions of people as demonstrably false. https://bit.ly/3jvXznE But again, I didn’t mention his name, because Fauci is not going to be part of the solution. His credibility is shot, and nothing he says will convince the skeptics to rethink their skepticism. (Earlier today, he slammed the Sturgis Bike Rally as a potential super-spreader event, while saying nothing about Obama’s birthday bash, and Lollapalooza. That’s the real problem. His slip is showing, and that’s made him unpersuasive to millions.
JL: Let’s stipulate that much of the medical establishment was slow to understand that the primary transmission mechanism for COVID was aerosolization. But the point here is that even Anthony Fauci, in this big gotcha moment, didn’t say that masks were “useless.” He used a heavily lawyered construct—no reason to be walking around with a mask—which was true. Also, Fauci allowed that masks might block “a droplet” while warning that it wasn’t the “perfect protection” some people thought. Again: Both factually correct. Was Fauci perfectly and fully transparent here? No. But neither was he saying what Rowe says.
MR: Again, I didn’t accuse Fauci of anything. I didn’t even mention his name. But the fact remains, we have tens of millions of highly skeptical, vaccine-hesitant Americans who no longer trust him. I don’t have to prove or justify their skepticism – it’s real, and the numbers prove it. Forty percent of the country is unvaccinated. Honest question, Jonathan - do you really think those Americans will be persuaded to think differently about the vaccine, when guys like you rush to defend men like Fauci and his “heavily lawyered constructs?"
JL: One more thing: By June, Fauci was admitting that he soft-peddled masks in early March because he was trying to keep people from hoarding them at a moment when the public wasn’t in danger and didn’t need them, but front-line workers were and front-line workers desperately did. Maybe you’re okay with the noble lie and maybe you’re not. But the fact is that people were hoarding them at the time. And if this episode discredited Fauci for you for all time, then there are myriad other health officials who can and have verified the vaccines’ efficacy.
MR: No, I’m not okay with a noble lie, or an ignoble one. Neither are millions of other people, who would prefer to hear the truth. Toward that end, I’m not comfortable telling people the vaccines are “perfectly safe” when the FDA has yet to approve them. As I said, “there is risk in everything, and I find it unpersuasive to pretend otherwise.” As for the vaccine’s efficacy, I could not have been clearer. My exact words on the matter – which you also omitted - were these.
“At this point, I’m afraid the government has but one course of sensible action - get the FDA on board, stat, and then, provide an honest, daily breakdown of just how quickly the virus is spreading among the unvaccinated, versus the vaccinated. No more threats, no more judgments, no more politics, no more celebrity-driven PSA’s, no more ham-fisted attempts at public shaming. Just a steady flow of verifiable data that definitively proves that the vast, undeniable, overwhelming majority of people who get this disease are unvaccinated.”
JL: And of course, if this episode discredited Fauci for you, then I assume that Donald Trump has also been discredited for you because of how he liked “playing down” COVID.
MR: Of course. Donald Trump should have apologized for that, and a few other things as well. Doing so might have made him more credible in the eyes of his many detractors. But Donald Trump, as you may have noticed, is no longer the president. And those now skeptical of the vaccine, are not limited to his former supporters. Far from it. Vaccine hesitancy is alive in well in every major city, particularly among minority populations.
JL: “A return to normalcy would occur just as soon as ‘the most vulnerable’ among us were vaccinated.” I’d like to see a cite for this.
MR: It’s the sentiment, Jonathan. It doesn’t matter who said it. I recall very clearly, a recurring talking point that revolved around “protecting the most vulnerable,” so the rest of us – (the less vulnerable) – could get back to work. If I was trying to build a case against specific individuals, I’d call people out. But that’s not what I’m trying to do. I’m trying to remind people that there’s never been a declarative statement about the metrics and circumstances that would allow us all to return to work, school, and play. And that’s a problem.
JL: The most high-profile example I can find making “back to normal predictions” is President Joe Biden who went in the opposite direction. On February 16, 2021, Biden said: “As my mother would say, with the grace of God and the goodwill of the neighbors, that by next Christmas I think we’ll be in a very different circumstance, God willing, than we are today. A year from now, I think that there’ll be significantly fewer people having to be socially distanced, having to wear a mask.” At the time, people lost their minds over this estimate because it was so pessimistic. But on February 16, we were still only getting 2.3 million doses administered per day and the government hadn’t yet solved the logistics problem left to it by the previous administration. And by the by, Biden’s pessimistic estimate is looking pretty dead-on right now, isn’t it?
MR: Beats me. I don’t have a crystal ball, and neither does the President. But I am starting to believe that COVID is likely here to stay, in some way, shape or variant. We’re going to have to learn to live with it, and I’m of the belief that doing so will be a lot easier if more people are vaccinated. I could be wrong, but that’s why I wrote what I wrote. I’m pro-vaccine, but anti-mandate. I’m also of the belief that half the country doesn’t trust anything Joe Biden says. You can blame the president for this, or you can call me a liar, or you can blame half the country for being unreasonably skeptical, but either way, this administration – just like the last one - has a massive, self-inflicted, credibility problem. I think it’s okay to acknowledge that. In fact, I think it’s critical that we do, if we hope to make a more persuasive case to those who believe they’ve been lied to.
JL: “Then, just as soon as ‘half the population’ was vaccinated.” Again, I have no idea who “those people” are. The medical and scientific establishments were exceedingly careful in not hanging numbers on what percentage of the population was needed to hit “herd immunity.” Most guesstimates put it in the mid-60s, but just about everyone involved was careful to acknowledge that they were dealing with too many unknowns to be making more than guesstimates.
MR: You’re right – there were lots of guesstimates being thrown around, but I think you’re mistaken about the care that people took to make sure those guesstimates were not taken at face value. The airwaves were filled with various experts and journalists talking with great certainty about the way everything would change when herd immunity was reached. I don’t blame them for being wrong – only for sounding certain. From the start of this mess, politicians, experts, and journalists have all been very long on certainty, and very short on humility. That too, has made them all less credible in the eyes of many.
JL: “Then, just as soon as we achieved ‘herd immunity’.” You know who pushed the idea of “herd immunity” over and over? The COVID deniers and anti-vaxxers. Those people. Those people who wanted to hold “chickenpox parties” for COVID instead of trying to mitigate the spread. Those people who kept insisting that no measures were needed to combat COVID because herd immunity would save us. Those people who declared we should just follow Sweden’s example and fast-forward to herd immunity. Those people whose medical advice in March of 2020 was “Get it. Get immunity. Feel better. The herd triumphs.” Mike Rowe is taking irresponsible bullshit from the bad guys and ascribing it to the good guys in an attempt to discredit them.
MR: Good guys? Bad guys? How shall I respond? With links to Nancy Pelosi, encouraging people to celebrate the Chinese New Year, cheek to jowl? Or Gavin Newsom, dining mask-less with his pals? Or Laurie Lightfoot, getting a haircut when no one else was allowed to? But what’s the point? This is the problem, Jonathan. You’re stuck in a gunfight. White hats and black hats and nothing in between. The point of my post, which you’re working very hard to ignore, is to acknowledge the undeniable fact that millions of Americans see the country exactly as you do - Good Guys vs. Bad Guys. And guess what? No one sees themselves as the Bad Guy. In the words of Dave Mason, “There ain't no good guy, there ain't no bad guy. There's only you and me and we just disagree.”
JL: “Those are the same people who told us they wouldn’t trust ANY vaccine developed under the last administration.” I’m sure you can find five people on Twitter who said something like it. Maybe even a guest on MSNBC. But show me serious people in the media, in medicine, in research, in politics—anywhere—who said such a thing?
MR: I’m talking here about the millions of Americans who would fundamentally distrust any vaccine recommended by Donald Trump if he were still in office today. If you don’t want to acknowledge that those people exist, please revisit the above quote from Dave Mason. Better yet, listen to it. https://bit.ly/3Cp9IU1 It might cheer you up.
JL: Maybe he’s talking about Kamala Harris? But she said something very different than what Rowe charges. Here’s what she said on September 6: “I would not trust Donald Trump. It would have to be a credible source of information that talks about the efficacy and the reliability of whatever he’s talking about. I will not take his word for it.” This is the big gotcha?
MR: No, Jonathan, I wasn’t talking about Harris, and no, it’s not a big “gotcha.” (But, for the record, she did say very clearly on 10/7/21 at the VP debate “If Donald Trump tells us to take it, I’m not taking it.” https://www.youtube.com/watch?v=-dAjCeMuXR0)
Again, I didn’t call her out by name, because it no longer matters if Kamala Harris should have trusted Donald Trump two years ago. What matters now, is that she and Trump and so many others have made themselves fundamentally unpersuasive to many millions of people. The issue at hand is how to persuade vaccine-hesitant Americans to reconsider their hesitancy. I propose we first acknowledge the reasons they distrust those in power and tell them the truth. You seem determined to dismiss their concerns and tell them their mistrust in our institutions is unjustified. With respect, I don’t think that’s going to work.
JL: And for his part, even in the fall of 2020, Joe Biden was worried that Trump’s mismanagement of the pandemic was going to make people reluctant to take a future vaccine. Here’s what he said: Why do we think, God willing, when we get a vaccine—that is good, works—why do we think the public is gonna line up to be willing to take the injection? We’ve lost so much confidence, the American people, in what’s said . . .Joe Biden was doing exactly the opposite of what Rowe says “those people” did. He was trying to argue against distrust of vaccines developed under Operation Warp Speed.
MR: That’s pretty rich, Jonathan. If Biden really wanted to champion vaccines in the Fall of 2020, he could have said, “My fellow Americans, I am praying that President Trump succeeds in his efforts to create a safe and effective vaccine in record time. I fully support his efforts to do so, and I am personally committed to doing all I can fight this disease, no matter what it means for my own future in politics.”
But he didn’t say that, Jonathan. Instead, he blamed Trump for creating a massive lack of trust among the American people. I get that. Trump failed badly at getting half the country to trust him. But can’t you see why the other half now sees President Biden in the exact same way?
JL: The reality is that our problem has been the exact opposite. The people who maintained over and over that COVID-19 wasn’t real, that it was an exaggeration, that it was a media conspiracy to hurt the Orange God King—many of those people now won’t take the vaccine because it has been administered by the new administration.
MR: How then, do you explain this, from the CDC. “Black and Hispanic people remain less likely than their White counterparts to have received a vaccine, leaving them at increased risk, particularly as the variant spreads.” https://bit.ly/2VA9Cs7 Weird, right? Did all those Black and Hispanic folks worship the Orange God King too?
JL: If Mike Rowe doesn’t want to encourage people to get vaccinated, that’s his right. That’s his privilege. But to go out in public and misrepresent recent history in an attempt to discredit vaccines is reprehensible.
MR: What’s reprehensible, and cowardly, is your attempt to mischaracterize what I wrote, and deliberately misinform your readers. If I really wanted to discourage people from getting vaccinated, why would I admit to getting vaccinated myself? And why would I write the passage you deliberately omitted? Here it is again, lest your readers forget it. “Vaccines have saved more lives than any other advancement in the long history of medicine, and to your point, I got the shots the minute I was eligible. – Mike Rowe.
JL: Rowe says he wants people to make their own decisions. Great. I celebrate everyone’s choices. But they should make them without Mike Rowe lying to them about the real things which happened in the real world.
MR: I’m happy to let the readers make up their own minds about who’s telling the truth. But let’s be clear about what you’ve done with your little slice of the Internet. You have ignored the point of my original post, omitted key passages regarding my actual position on vaccines, written a damning and fallacious headline, and picked a fight with a guy who just reminded six million people that the overwhelming majority of Americans currently hospitalized with COVID have not been vaccinated. Oh yeah, AND told them that he got the shot as soon as he was able. That was the point of my post, Jonathan.
What was the point of yours?
Mike
74K Likes
7.5K Comments
10K Shares
Mike Rowe
August 5 at 10:53 AM ·
Off the Wall
Mike – I read several months ago that you got the vaccine. I’m glad. But I’m also curious. You have a lot of people on this page who respect your opinion - many of whom I’d wager are unvaccinated. Have you encouraged them to follow your example? If not, what are you waiting for? As you surely know, Delta is raging. The sooner we’re all vaccinated, the sooner we can get back to normal!
Steve Manchin
Hi Steve
The short answer is no - I have not publicly encouraged anyone to get vaccinated. In fact, I have recently declined to participate in several PSA's designed to persuade people to get the jab. That’s not because I’m opposed to vaccines, obviously. Vaccines have saved more lives than any other advancement in the long history of medicine, and to your point, I got the shots the minute I was eligible. But I’m not a doctor, Steve, and even though I occasionally play one on TV, I’m not inclined to dispense medical advice to the people on this page.
True, I did appear in a few PSA’s early on, back when they assured us that locking down was essential to keeping our hospitals from being overrun. “Two weeks to flatten the curve!” Remember that one? That of course, turned out to be untrue, and I regret my role in helping perpetuate that particular falsehood. I also regret what I said during the first Zoom show to air in primetime. It was an episode of After the Catch, where I discussed the lockdowns with a few crab-boat captains. At one point, I looked into the camera lens on my computer and said, with uncharacteristic earnestness, “For the first time in a long time, it appears we’re all in the same boat.”
Well, I was wrong about that, too. We were not in the same boat, not then or now. We were in the same storm, but our boats were very different. Some prospered during the lockdowns and rode out the gale in yachts and pleasure crafts. Others floundered and weathered the storm in rowboats and dinghies. Some had no boat at all and hung on for dear life to whatever flotsam and jetsam they could find. Point is, I said some things I regret back then, and spoke too broadly to too many. Thus, the only thing I’ll say now regarding the vaccine, is that there is risk in everything we do, and there is risk in everything we don’t do. Thus, there is risk in getting vaccinated, and there is risk in not getting vaccinated. Obviously, I made my decision, but again, I’m not a doctor. Thus, I am not equipped to answer questions like, “But Mike, if the vaccine is so safe, why hasn’t the FDA approved it? Or, “But Mike, if the vaccine is so effective, why is the government now treating us all as if we’re unvaccinated?”
These are fair and reasonable questions, and I have no logical reply. Here in California if you’re inside, you must now wear a mask, vaccinated or not. What kind of message does that send?Yes, we have a new variant, and from what I’ve read, it’s highly contagious, but far less virulent – especially if you’re vaccinated. According to the CDC, just one 1 in 27,000 vaccinated people have contracted it. That means if you’re vaccinated, you’re more likely to get struck by lightning than contract COVID. And yet, people are once again calling for more lockdowns, more restrictions, and more compliance from those who already got their shots.
The fact is, millions of reasonable Americans have every right to feel confused and skeptical. Those people you refer to, Steve – the ones now telling us that we can “get back to normal just as soon as everyone is vaccinated” – those are the same people who said, “two weeks to flatten the curve!” Those are the same people who told us that masks were “useless” before they told us they were “critical.” Those are the same people who told us that a return to normalcy would occur just as soon as “the most vulnerable” among us were vaccinated. Then, just as soon as “half the population” was vaccinated. Then, just as soon as we achieved “herd immunity.” Those are the same people who told us they wouldn’t trust ANY vaccine developed under the last administration. Now, those very same people are belittling the skeptics!
If this were a Peanuts cartoon, those people would be Lucy, pulling away the football at the last moment while a nation full of Charlie Browns land flat on their collective back, over and over and over again. Those people you refer to - elected officials, journalists, and most disturbingly, more than a few medical experts - have moved the goalposts time and time again, while ignoring the same rules and restrictions they demand we all live by. They’re always certain, usually wrong, incapable of shame, and utterly void of humility. Is it any wonder millions find them unpersuasive?
I’m sorry, Steve, but even if I were an actual doctor, I wouldn’t know what to say to the skeptics on this page. But as a fake one, I’ll say this. Every single American who wants the vaccine has had the opportunity to get it – for free. Those who have declined will not be persuaded by the likes of me. At this point, I’m afraid the the government has but one course of sensible action - get the FDA on board, stat, and then, provide an honest, daily breakdown of just how quickly the virus is spreading among the unvaccinated, versus the vaccinated. No more threats, no more judgments, no more politics, no more celebrity-driven PSA’s, no more ham-fisted attempts at public shaming. Just a steady flow of verifiable data that definitively proves that the vast, undeniable, overwhelming majority of people who get this disease are unvaccinated.
In other words, give us the facts, admit your mistakes, try on a bit of humility, and stop treating the unvaccinated like the enemy.
Mike
PS Dirty Jobs, as the attached photo should prove, is coming back. New episodes probably start in October. The doctor will see you then...
93K Likes
11K Comments
42K Shares
Fly solo in 1 hour! How about flight lessons for $5? Or maybe you want $1 Million of aircraft insurance for $50. Check out these awesome ads from the golden age of aviation...
The following ads were found in vintage copies of AOPA Pilot, The Curtis Wright Review, and Aero Digest.
Avatar
Tennessee_Tech
6 hours ago
So let's make this simple for people..
1) You make stuff or provide a service that people want, can pay for, and within your reach of delivery.
2) You charge them for the price that they are willing to pay and you are willing to accept.
This has nothing to do with your failures or the cost to develop something, only the value of the transaction to them.
Consequences of this reality..
1) You provide a product or service that people don't want or aren't willing to pay what it costs you to provide and you go out of business. e.g. Blockbuster
2) You make enough mistakes / failures on products, services, etc.. and you aren't in business any longer.
So let's talk about when we start making exceptions.. And the implications..
S1) We need drugs, semiconductors, cars, steel, etc.. produced here so we aren't dependent on China, India, etc..
R1) We do need certain things securely and properly produced in country, even regionally. So reduction of regulation, market driven wages / benefits, etcetera are how you encourage (not make) that happen.
Government intervention / regulation / subsidies are "soft" fascism..
https://www.econlib.org/lib...
Where socialism sought totalitarian control of a society’s economic processes through direct state operation of the means of production, fascism sought that control indirectly, through domination of nominally private owners. Where socialism nationalized property explicitly, fascism did so implicitly, by requiring owners to use their property in the “national interest”—that is, as the autocratic authority conceived it. (Nevertheless, a few industries were operated by the state.) Where socialism abolished all market relations outright, fascism left the appearance of market relations while planning all economic activities. Where socialism abolished money and prices, fascism controlled the monetary system and set all prices and wages politically. In doing all this, fascism denatured the marketplace. Entrepreneurship was abolished. State ministries, rather than consumers, determined what was produced and under what conditions
The class-action lawsuit alleges that Sanofi, Eli Lilly, Novo Nordisk and AstraZeneca colluded in the summer of 2020 to restrict offering discounted products to 340B contract pharmacies.
The drugmakers should compete against each other, but instead “they worked together to boost their profits by coordinating to retract a long-standing discount for safety-net hospitals and clinics,” the lawsuit filed in the U.S. District Court for the Western District of New York said.
Mosaic argues that last summer the four drugmakers spent millions lobbying the federal government to limit 340B drug discounts for diabetes medicines such as insulin.
However, former President Donald Trump in July 2020 issued an executive order that aimed to ensure 1,000 community health centers would get insulin and injectable epinephrine at the 340B discounted rate.
While 340b is in effect, multiple drugmakers are allegedly moving to restrict the sale of insulin to healthcare providers at the reduced rate under the 340b program.
Arthur Schwartz
@ArthurSchwartz
Remember when @brianstelter dismissed Tucker’s claims as conspiracy theory nonsense? Does Stelter ever get anything right?
Tucker Carlson’s Spying Allegations Being Investigated by National Security Agency Watchdog
wsj.com //
WASHINGTON—The National Security Agency’s internal watchdog is conducting a review of recent allegations made by Fox News host Tucker Carlson that the spy agency had improperly targeted his communications for surveillance, the agency and an official said.
The announcement of the review by the NSA’s inspector general doesn’t mention Mr. Carlson by name, but instead refers to a member of the U.S. news media. A person familiar with the matter said the review concerns Mr. Carlson.
Q: How to delete all but last [n] ZFS snapshots?
Does anyone have any good ways / scripts they use to manage the number of snapshots stored on their ZFS systems? Ideally, I'd like a script that iterates through all the snapshots for a given ZFS filesystem and deletes all but the last n snapshots for that filesystem.
E.g. I've got two filesystems, one called tank and another called sastank. Snapshots are named with the date on which they were created: sastank@AutoD-2011-12-13 so a simple sort command should list them in order. I'm looking to keep the last 2 week's worth of daily snapshots on tank, but only the last two days worth of snapshots on sastank.
A:
zfs list -t snapshot -o name | grep ^tank@Auto | tac | tail -n +16 | xargs -n 1 zfs destroy -r
- Output the list of the snapshot (names only) with zfs list -t snapshot -o name
- Filter to keep only the ones that match tank@Auto with grep ^tank@Auto
- Reverse the list (previously sorted from oldest to newest) with tac
- Limit output to the 16th oldest result and following with tail -n +16
- Then destroy with xargs -n 1 zfs destroy -vr
Deleting snapshots in reverse order is supposedly more efficient or sort in reverse order of creation.
zfs list -t snapshot -o name -S creation | grep ^tank@Auto | tail -n +16 | xargs -n 1 zfs destroy -vr
A:
More general case of getting most recent snapshot based on creation date, not by name.
zfs list -H -t snapshot -o name -S creation | head -1
Scoped to a specific filesystem name TestOne
zfs list -H -t snapshot -o name -S creation -d1 TestOne | head -1
-H: No header so that first line is a snapshot name
-t snapshot: List snapshots (list can list other things like pools and volumes)
-o name: Display the snapshot name property.
-S creation: Capital S denotes descending sort, based on creation time. This puts most recent snapshot as the first line.
-d1 TestOne: Says include children, which seems confusing but its because as far as this command is concerned, snapshots of TestOne are children. This will NOT list snapshots of volumes within TestOne such as TestOne/SubVol@someSnapshot.
| head -1: Pipe to head and only return first line. //
Thanks for the -d1. That was the key to the question "How do I get all snapshots for a given dataset?"
Senator Rand Paul
@RandPaul
We are at a moment of truth and a crossroads. Will we allow these people to use fear and propaganda to do further harm to our society, economy, and children?
Or will we stand together and say, absolutely not. Not this time. I choose freedom. //
WATCH: Rand Paul Blasts Dem Tyrants and Mandates, Causing a Leftist Meltdown
By Nick Arama | Aug 09, 2021 11:30 AM ET
Stefani Reynolds/The New York Times via AP, Pool
Sen. Rand Paul (R-KY) put out a powerful video against any further lockdowns and it’s driving folks on the left wild.
Paul made it very simple, saying that we were done with any more lockdowns and if they tried to impose them again, “It’s time to resist.”
Paul ripped apart mandates, starting with the mandate on mask wearing on House members.
“They can’t arrest all of us. They can’t keep all of your kids home from school. They can’t keep every government building closed – although I’ve got a long list of ones they might keep closed or might ought to keep closed. We don’t have to accept the mandates, lockdowns, and harmful policies of the petty tyrants and bureaucrats. We can simply say no, not again. Nancy Pelosi — you will not arrest or stop me or anyone on my staff from doing our jobs. We have either had COVID, had the vaccine, or been offered the vaccine. We will make our own health choices. We will not show you a passport, we will not wear a mask, we will not be forced into random screenings and testings so you can continue your drunk-with-power rein over the Capitol.”